@@ -1,6 +1,6 @@
 from boardwatch_models.board import Board
-from boardwatch_models.board_maker import BoardMaker
 from boardwatch_models.game import Game
 from boardwatch_models.listing import Listing
 from boardwatch_models.platform import Platform
 from boardwatch_models.platform_edition import PlatformEdition
+from boardwatch_models.platform_name_group import PlatformNameGroup
